@@ -3,14 +3,20 @@
 @Author  :   g1879
 @Contact :   g1879@qq.com
 """
-
-from warnings import filterwarnings
-
-filterwarnings('ignore')
-from .mix_page import MixPage
-from .web_page import WebPage
+# 常用页面类
 from .chromium_page import ChromiumPage
 from .session_page import SessionPage
-from .drission import Drission
-from .config import DriverOptions, SessionOptions
+from .web_page import WebPage
+
+# 启动配置类
+from .configs.chromium_options import ChromiumOptions
+from .configs.session_options import SessionOptions
+
+# 常用工具
 from .action_chains import ActionChains
+from .keys import Keys
+
+# 旧版页面类和启动配置类
+from .mix_page import MixPage
+from .drission import Drission
+from .configs.driver_options import DriverOptions
