@@ -10,7 +10,7 @@ class ChromiumTab(ChromiumBase):
     """实现浏览器标签页的类"""
 
     def __init__(self, page, tab_id=None):
-        """初始化                                                      \n
+        """
         :param page: ChromiumPage对象
         :param tab_id: 要控制的标签页id，不指定默认为激活的
         """
@@ -18,7 +18,6 @@ class ChromiumTab(ChromiumBase):
         super().__init__(page.address, tab_id, page.timeout)
 
     def _set_options(self):
-        self.set_timeouts(page_load=self.page.timeouts.page_load,
-                          script=self.page.timeouts.script,
-                          implicit=self.page.timeouts.implicit if self.timeout is None else self.timeout)
+        """重写设置浏览器运行参数方法"""
+        self._timeouts = self.page.timeouts
         self._page_load_strategy = self.page.page_load_strategy
