@@ -5,27 +5,25 @@
 """
 from os import popen
 from pathlib import Path
-from pprint import pprint
 from re import search
 from typing import Union
 
 from selenium import webdriver
 
-from .common import unzip
-from .config import OptionsManager, DriverOptions
+from .configs.chromium_options import ChromiumOptions
+from .configs.driver_options import DriverOptions
+from .configs.options_manage import OptionsManager
 from .drission import Drission
+from .functions.tools import unzip
 from .session_page import SessionPage
 
 
 def show_settings(ini_path=None):
-    """打印ini文件内容"""
-    om = OptionsManager(ini_path)
-    print('paths:')
-    pprint(om.get_option('paths'))
-    print('\nchrome options:')
-    pprint(om.get_option('chrome_options'))
-    print('\nsession options:')
-    pprint(om.get_option('session_options'))
+    """打印ini文件内容
+    :param ini_path: ini文件路径
+    :return: None
+    """
+    OptionsManager(ini_path).show()
 
 
 def set_paths(driver_path=None,
@@ -33,20 +31,18 @@ def set_paths(driver_path=None,
               browser_path=None,
               local_port=None,
               debugger_address=None,
-              tmp_path=None,
               download_path=None,
               user_data_path=None,
               cache_path=None,
               ini_path=None,
               check_version=False):
-    """快捷的路径设置函数                                          \n
+    """快捷的路径设置函数
     :param driver_path: chromedriver.exe路径
-    :param chrome_path: chrome.exe路径
+    :param chrome_path: 浏览器可执行文件路径
     :param browser_path: 浏览器可执行文件路径
     :param local_port: 本地端口号
     :param debugger_address: 调试浏览器地址，例：127.0.0.1:9222
     :param download_path: 下载文件路径
-    :param tmp_path: 临时文件夹路径
     :param user_data_path: 用户数据路径
     :param cache_path: 缓存路径
     :param ini_path: 要修改的ini文件路径
@@ -56,7 +52,7 @@ def set_paths(driver_path=None,
     om = OptionsManager(ini_path)
 
     def format_path(path: str) -> str:
-        return path or ''
+        return str(path) if path else ''
 
     if driver_path is not None:
         om.set_item('paths', 'chromedriver_path', format_path(driver_path))
@@ -68,18 +64,13 @@ def set_paths(driver_path=None,
         om.set_item('chrome_options', 'binary_location', format_path(browser_path))
 
     if local_port is not None:
-        om.set_item('chrome_options', 'debugger_address', format_path(f'127.0.0.1:{local_port}'))
+        om.set_item('chrome_options', 'debugger_address', f'127.0.0.1:{local_port}')
 
     if debugger_address is not None:
-        om.set_item('chrome_options', 'debugger_address', format_path(debugger_address))
-
-    if tmp_path is not None:
-        om.set_item('paths', 'tmp_path', format_path(tmp_path))
+        om.set_item('chrome_options', 'debugger_address', debugger_address)
 
     if download_path is not None:
-        experimental_options = om.get_value('chrome_options', 'experimental_options')
-        experimental_options['prefs']['download.default_directory'] = format_path(download_path)
-        om.set_item('chrome_options', 'experimental_options', experimental_options)
+        om.set_item('paths', 'download_path', format_path(download_path))
 
     om.save()
 
@@ -90,77 +81,85 @@ def set_paths(driver_path=None,
         set_argument('--disk-cache-dir', format_path(cache_path), ini_path)
 
     if check_version:
-        check_driver_version(format_path(driver_path), format_path(chrome_path))
+        check_driver_version(format_path(driver_path), format_path(browser_path))
 
 
-def set_argument(arg, value, ini_path=None):
-    """设置浏览器配置argument属性                            \n
-    :param arg: 属性名
-    :param value: 属性值，有值的属性传入值，没有的传入bool
+def use_auto_port(on_off=True, ini_path=None):
+    """设置启动浏览器时使用自动分配的端口和临时文件夹
+    :param on_off: 是否开启自动端口
     :param ini_path: 要修改的ini文件路径
     :return: None
     """
-    do = DriverOptions(ini_path=ini_path)
-    do.remove_argument(arg)
+    if not isinstance(on_off, bool):
+        raise TypeError('on_off参数只能输入bool值。')
+    om = OptionsManager(ini_path)
+    om.set_item('chrome_options', 'auto_port', on_off)
+    om.save()
 
-    if value:
-        arg_str = arg if isinstance(value, bool) else f'{arg}={value}'
-        do.add_argument(arg_str)
 
-    do.save()
+def set_argument(arg, value=None, ini_path=None):
+    """设置浏览器配置argument属性
+    :param arg: 属性名
+    :param value: 属性值，有值的属性传入值，没有的传入None
+    :param ini_path: 要修改的ini文件路径
+    :return: None
+    """
+    co = ChromiumOptions(ini_path=ini_path)
+    co.set_argument(arg, value)
+    co.save()
 
 
 def set_headless(on_off=True, ini_path=None):
-    """设置是否隐藏浏览器界面               \n
+    """设置是否隐藏浏览器界面
     :param on_off: 开或关
     :param ini_path: 要修改的ini文件路径
     :return: None
     """
-    on_off = True if on_off else False
+    on_off = None if on_off else False
     set_argument('--headless', on_off, ini_path)
 
 
 def set_no_imgs(on_off=True, ini_path=None):
-    """设置是否禁止加载图片                    \n
+    """设置是否禁止加载图片
     :param on_off: 开或关
     :param ini_path: 要修改的ini文件路径
     :return: None
     """
-    on_off = True if on_off else False
+    on_off = None if on_off else False
     set_argument('--blink-settings=imagesEnabled=false', on_off, ini_path)
 
 
 def set_no_js(on_off=True, ini_path=None):
-    """设置是否禁用js                              \n
+    """设置是否禁用js
     :param on_off: 开或关
     :param ini_path: 要修改的ini文件路径
     :return: None
     """
-    on_off = True if on_off else False
+    on_off = None if on_off else False
     set_argument('--disable-javascript', on_off, ini_path)
 
 
 def set_mute(on_off=True, ini_path=None):
-    """设置是否静音                              \n
+    """设置是否静音
     :param on_off: 开或关
     :param ini_path: 要修改的ini文件路径
     :return: None
     """
-    on_off = True if on_off else False
+    on_off = None if on_off else False
     set_argument('--mute-audio', on_off, ini_path)
 
 
 def set_user_agent(user_agent, ini_path=None):
-    """设置user agent                           \n
+    """设置user agent
     :param user_agent: user agent文本
     :param ini_path: 要修改的ini文件路径
     :return: None
     """
-    set_argument('user-agent', user_agent, ini_path)
+    set_argument('--user-agent', user_agent, ini_path)
 
 
 def set_proxy(proxy, ini_path=None):
-    """设置代理                                  \n
+    """设置代理
     :param proxy: 代理网址和端口
     :param ini_path: 要修改的ini文件路径
     :return: None
@@ -169,7 +168,7 @@ def set_proxy(proxy, ini_path=None):
 
 
 def check_driver_version(driver_path=None, chrome_path=None):
-    """检查传入的chrome和chromedriver是否匹配  \n
+    """检查传入的chrome和chromedriver是否匹配
     :param driver_path: chromedriver.exe路径
     :param chrome_path: chrome.exe路径
     :return: 是否匹配
@@ -204,7 +203,7 @@ def get_match_driver(ini_path='default',
                      chrome_path=None,
                      show_msg=True,
                      check_version=True):
-    """自动识别chrome版本并下载匹配的driver             \n
+    """自动识别chrome版本并下载匹配的driver
     :param ini_path: 要读取和修改的ini文件路径
     :param save_path: chromedriver保存路径
     :param chrome_path: 指定chrome.exe位置
@@ -256,7 +255,7 @@ def get_chrome_path(ini_path=None,
                     from_ini=True,
                     from_regedit=True,
                     from_system_path=True):
-    """从ini文件或系统变量中获取chrome.exe的路径    \n
+    """从ini文件或系统变量中获取chrome.exe的路径
     :param ini_path: ini文件路径
     :param show_msg: 是否打印信息
     :param from_ini: 是否从ini文件获取
@@ -329,7 +328,7 @@ def get_chrome_path(ini_path=None,
 
 
 def _get_chrome_version(path: str) -> Union[str, None]:
-    """根据文件路径获取版本号              \n
+    """根据文件路径获取版本号
     :param path: chrome.exe文件路径
     :return: 版本号
     """
@@ -346,7 +345,7 @@ def _get_chrome_version(path: str) -> Union[str, None]:
 
 
 def _download_driver(version: str, save_path: str = None, show_msg: bool = True) -> Union[str, None]:
-    """根据传入的版本号到镜像网站查找，下载最相近的          \n
+    """根据传入的版本号到镜像网站查找，下载最相近的
     :param version: 本地版本号
     :return: 保存地址
     """
