@@ -13,7 +13,8 @@ from requests.structures import CaseInsensitiveDict
 from tldextract import extract
 
 from .base import BasePage
-from .config import SessionOptions, cookies_to_tuple, cookie_to_dict
+from .configs.session_options import SessionOptions
+from .functions.web import cookie_to_dict, set_session_cookies
 from .session_element import SessionElement, make_session_ele
 
 
@@ -21,12 +22,12 @@ class SessionPage(BasePage):
     """SessionPage封装了页面操作的常用功能，使用requests来获取、解析网页"""
 
     def __init__(self, session_or_options=None, timeout=None):
-        """初始化                                                     \n
+        """
         :param session_or_options: Session对象或SessionOptions对象
         :param timeout: 连接超时时间，为None时从ini文件读取
         """
         self._response = None
-        self.timeout = 10
+        self._download_set = None
         self._create_session(session_or_options)
         timeout = timeout if timeout is not None else self.timeout
         super().__init__(timeout)
@@ -37,47 +38,51 @@ class SessionPage(BasePage):
         :return: None
         """
         if Session_or_Options is None or isinstance(Session_or_Options, SessionOptions):
-            options = Session_or_Options or SessionOptions()
-            self._set_session(options.as_dict())
-            self.timeout = options.timeout
+            self._session_options = Session_or_Options or SessionOptions()
+            self._set_session(self._session_options)
+
         elif isinstance(Session_or_Options, Session):
             self._session = Session_or_Options
+            self._session_options = SessionOptions(read_file=False)
 
-    def _set_session(self, data):
-        """根据传入字典对session进行设置    \n
-        :param data: session配置字典
+        self._set_options()
+
+    def _set_session(self, opt):
+        """根据传入字典对session进行设置
+        :param opt: session配置字典
         :return: None
         """
         self._session = Session()
 
-        if 'headers' in data:
-            self._session.headers = CaseInsensitiveDict(data['headers'])
-        if 'cookies' in data:
-            self.set_cookies(data['cookies'])
+        if opt.headers:
+            self._session.headers = CaseInsensitiveDict(opt.headers)
+        if opt.cookies:
+            self.set_cookies(opt.cookies)
+        if opt.adapters:
+            for url, adapter in opt.adapters:
+                self._session.mount(url, adapter)
 
         attrs = ['auth', 'proxies', 'hooks', 'params', 'verify',
-                 'cert', 'stream', 'trust_env', 'max_redirects']  # , 'adapters'
+                 'cert', 'stream', 'trust_env', 'max_redirects']
         for i in attrs:
-            if i in data:
-                self._session.__setattr__(i, data[i])
+            attr = opt.__getattribute__(i)
+            if attr:
+                self._session.__setattr__(i, attr)
+
+    def _set_options(self):
+        """设置WebPage中与d模式共用的配置，便于WebPage覆盖掉"""
+        self._timeout = self._session_options.timeout
+        self._download_path = self._session_options.download_path
 
     def set_cookies(self, cookies):
-        cookies = cookies_to_tuple(cookies)
-        for cookie in cookies:
-            if cookie['value'] is None:
-                cookie['value'] = ''
-
-            kwargs = {x: cookie[x] for x in cookie
-                      if x.lower() in ('version', 'port', 'domain', 'path', 'secure',
-                                       'expires', 'discard', 'comment', 'comment_url', 'rest')}
-
-            if 'expiry' in cookie:
-                kwargs['expires'] = cookie['expiry']
-
-            self.session.cookies.set(cookie['name'], cookie['value'], **kwargs)
+        """为Session对象设置cookies
+        :param cookies: cookies信息
+        :return: None
+        """
+        set_session_cookies(self.session, cookies)
 
     def set_headers(self, headers):
-        """设置通用的headers，设置的headers值回逐个覆盖原有的，不会清理原来的        \n
+        """设置通用的headers，设置的headers值回逐个覆盖原有的，不会清理原来的
         :param headers: dict形式的headers
         :return: None
         """
@@ -86,8 +91,8 @@ class SessionPage(BasePage):
             self.session.headers[i] = headers[i]
 
     def __call__(self, loc_or_str, timeout=None):
-        """在内部查找元素                                                  \n
-        例：ele2 = ele1('@id=ele_id')                                     \n
+        """在内部查找元素
+        例：ele2 = ele1('@id=ele_id')
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 不起实际作用，用于和DriverElement对应，便于无差别调用
         :return: SessionElement对象或属性文本
@@ -113,8 +118,35 @@ class SessionPage(BasePage):
         except Exception:
             return None
 
+    @property
+    def download_path(self):
+        """返回下载路径"""
+        return self._download_path
+
+    @property
+    def download_set(self):
+        """返回用于设置下载参数的对象"""
+        if self._download_set is None:
+            self._download_set = DownloadSetter(self)
+        return self._download_set
+
+    @property
+    def download(self):
+        """返回下载器对象"""
+        return self.download_set.DownloadKit
+
+    @property
+    def session(self):
+        """返回session对象"""
+        return self._session
+
+    @property
+    def response(self):
+        """返回访问url得到的response对象"""
+        return self._response
+
     def get(self, url, show_errmsg=False, retry=None, interval=None, timeout=None, **kwargs):
-        """用get方式跳转到url                                 \n
+        """用get方式跳转到url
         :param url: 目标url
         :param show_errmsg: 是否显示和抛出异常
         :param retry: 重试次数
@@ -126,7 +158,7 @@ class SessionPage(BasePage):
         return self._s_connect(url, 'get', None, show_errmsg, retry, interval, **kwargs)
 
     def ele(self, loc_or_ele, timeout=None):
-        """返回页面中符合条件的第一个元素、属性或节点文本                            \n
+        """返回页面中符合条件的第一个元素、属性或节点文本
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :param timeout: 不起实际作用，用于和DriverElement对应，便于无差别调用
         :return: SessionElement对象或属性、文本
@@ -134,7 +166,7 @@ class SessionPage(BasePage):
         return self._ele(loc_or_ele)
 
     def eles(self, loc_or_str, timeout=None):
-        """返回页面中所有符合条件的元素、属性或节点文本                          \n
+        """返回页面中所有符合条件的元素、属性或节点文本
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 不起实际作用，用于和DriverElement对应，便于无差别调用
         :return: SessionElement对象或属性、文本组成的列表
@@ -142,21 +174,21 @@ class SessionPage(BasePage):
         return self._ele(loc_or_str, single=False)
 
     def s_ele(self, loc_or_ele=None):
-        """返回页面中符合条件的第一个元素、属性或节点文本                          \n
+        """返回页面中符合条件的第一个元素、属性或节点文本
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
         """
         return make_session_ele(self.html) if loc_or_ele is None else self._ele(loc_or_ele)
 
     def s_eles(self, loc_or_str):
-        """返回页面中符合条件的所有元素、属性或节点文本                              \n
+        """返回页面中符合条件的所有元素、属性或节点文本
         :param loc_or_str: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
         """
         return self._ele(loc_or_str, single=False)
 
     def _ele(self, loc_or_ele, timeout=None, single=True):
-        """返回页面中符合条件的元素、属性或节点文本，默认返回第一个                                           \n
+        """返回页面中符合条件的元素、属性或节点文本，默认返回第一个
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :param timeout: 不起实际作用，用于和父类对应
         :param single: True则返回第一个，False则返回全部
@@ -165,7 +197,7 @@ class SessionPage(BasePage):
         return loc_or_ele if isinstance(loc_or_ele, SessionElement) else make_session_ele(self, loc_or_ele, single)
 
     def get_cookies(self, as_dict=False, all_domains=False):
-        """返回cookies                               \n
+        """返回cookies
         :param as_dict: 是否以字典方式返回
         :param all_domains: 是否返回所有域的cookies
         :return: cookies信息
@@ -185,27 +217,8 @@ class SessionPage(BasePage):
         else:
             return [cookie_to_dict(cookie) for cookie in cookies]
 
-    # ----------------session独有属性和方法-----------------------
-    @property
-    def session(self):
-        """返回session对象"""
-        return self._session
-
-    @property
-    def response(self):
-        """返回访问url得到的response对象"""
-        return self._response
-
-    @property
-    def download(self):
-        """返回下载器对象"""
-        if not hasattr(self, '_download_kit'):
-            self._download_kit = DownloadKit(session=self)
-
-        return self._download_kit
-
     def post(self, url, data=None, show_errmsg=False, retry=None, interval=None, **kwargs):
-        """用post方式跳转到url                                 \n
+        """用post方式跳转到url
         :param url: 目标url
         :param data: 提交的数据
         :param show_errmsg: 是否显示和抛出异常
@@ -217,7 +230,7 @@ class SessionPage(BasePage):
         return self._s_connect(url, 'post', data, show_errmsg, retry, interval, **kwargs)
 
     def _s_connect(self, url, mode, data=None, show_errmsg=False, retry=None, interval=None, **kwargs):
-        """执行get或post连接                                 \n
+        """执行get或post连接
         :param url: 目标url
         :param mode: 'get' 或 'post'
         :param data: 提交的数据
@@ -245,7 +258,7 @@ class SessionPage(BasePage):
         return self._url_available
 
     def _make_response(self, url, mode='get', data=None, retry=None, interval=None, show_errmsg=False, **kwargs):
-        """生成Response对象                                                    \n
+        """生成Response对象
         :param url: 目标url
         :param mode: 'get' 或 'post'
         :param data: post方式要提交的数据
@@ -312,6 +325,68 @@ class SessionPage(BasePage):
             return r, f'状态码：{r.status_code}'
 
 
+class DownloadSetter(object):
+    """用于设置下载参数的类"""
+
+    def __init__(self, page):
+        self._page = page
+        self._DownloadKit = None
+
+    @property
+    def DownloadKit(self):
+        if self._DownloadKit is None:
+            self._DownloadKit = DownloadKit(session=self._page, goal_path=self._page.download_path)
+        return self._DownloadKit
+
+    @property
+    def if_file_exists(self):
+        """返回用于设置存在同名文件时处理方法的对象"""
+        return FileExists(self)
+
+    def split(self, on_off):
+        """设置是否允许拆分大文件用多线程下载
+        :param on_off: 是否启用多线程下载大文件
+        :return: None
+        """
+        self.DownloadKit.split = on_off
+
+    def save_path(self, path):
+        """设置下载保存路径
+        :param path: 下载保存路径
+        :return: None
+        """
+        path = path if path is None else str(path)
+        self._page._download_path = path
+        self.DownloadKit.goal_path = path
+
+
+class FileExists(object):
+    """用于设置存在同名文件时处理方法"""
+
+    def __init__(self, setter):
+        """
+        :param setter: DownloadSetter对象
+        """
+        self._setter = setter
+
+    def __call__(self, mode):
+        if mode not in ('skip', 'rename', 'overwrite'):
+            raise ValueError("mode参数只能是'skip', 'rename', 'overwrite'")
+        self._setter.DownloadKit.file_exists = mode
+
+    def skip(self):
+        """设为跳过"""
+        self._setter.DownloadKit.file_exists = 'skip'
+
+    def rename(self):
+        """设为重命名，文件名后加序号"""
+        self._setter.DownloadKit._file_exists = 'rename'
+
+    def overwrite(self):
+        """设为覆盖"""
+        self._setter.DownloadKit._file_exists = 'overwrite'
+
+
 def check_headers(kwargs, headers, arg) -> bool:
     """检查kwargs或headers中是否有arg所示属性"""
     return arg in kwargs['headers'] or arg in headers
