@@ -9,7 +9,7 @@ from typing import Union
 from selenium.webdriver.remote.webelement import WebElement
 
 from .base import BaseElement
-from .common import get_loc
+from .functions.locator import get_loc
 from .driver_element import make_driver_ele
 from .session_element import make_session_ele, SessionElement
 
@@ -30,8 +30,8 @@ class ShadowRootElement(BaseElement):
         return f'<ShadowRootElement in {self.parent_ele} >'
 
     def __call__(self, loc_or_str, timeout=None):
-        """在内部查找元素                                            \n
-        例：ele2 = ele1('@id=ele_id')                               \n
+        """在内部查找元素
+        例：ele2 = ele1('@id=ele_id')
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 超时时间
         :return: DriverElement对象或属性、文本
@@ -54,7 +54,7 @@ class ShadowRootElement(BaseElement):
         return shadow_root.get_attribute('innerHTML')
 
     def parent(self, level_or_loc=1):
-        """返回上面某一级父元素，可指定层数或用查询语法定位              \n
+        """返回上面某一级父元素，可指定层数或用查询语法定位
         :param level_or_loc: 第几级父元素，或定位符
         :return: DriverElement对象
         """
@@ -75,7 +75,7 @@ class ShadowRootElement(BaseElement):
         return self.parent_ele.ele(loc, timeout=0)
 
     def next(self, index=1, filter_loc=''):
-        """返回后面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
+        """返回后面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个
         :param index: 第几个查询结果元素
         :param filter_loc: 用于筛选元素的查询语法
         :return: DriverElement对象
@@ -84,7 +84,7 @@ class ShadowRootElement(BaseElement):
         return nodes[index - 1] if nodes else None
 
     def before(self, index=1, filter_loc=''):
-        """返回前面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
+        """返回前面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个
         :param index: 前面第几个查询结果元素
         :param filter_loc: 用于筛选元素的查询语法
         :return: 本元素前面的某个元素或节点
@@ -93,7 +93,7 @@ class ShadowRootElement(BaseElement):
         return nodes[index - 1] if nodes else None
 
     def after(self, index=1, filter_loc=''):
-        """返回后面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
+        """返回后面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个
         :param index: 后面第几个查询结果元素
         :param filter_loc: 用于筛选元素的查询语法
         :return: 本元素后面的某个元素或节点
@@ -102,7 +102,7 @@ class ShadowRootElement(BaseElement):
         return nodes[index - 1] if nodes else None
 
     def nexts(self, filter_loc=''):
-        """返回后面所有兄弟元素或节点组成的列表        \n
+        """返回后面所有兄弟元素或节点组成的列表
         :param filter_loc: 用于筛选元素的查询语法
         :return: DriverElement对象组成的列表
         """
@@ -115,7 +115,7 @@ class ShadowRootElement(BaseElement):
         return self.parent_ele.eles(xpath, timeout=0.1)
 
     def befores(self, filter_loc=''):
-        """返回后面全部兄弟元素或节点组成的列表，可用查询语法筛选        \n
+        """返回后面全部兄弟元素或节点组成的列表，可用查询语法筛选
         :param filter_loc: 用于筛选元素的查询语法
         :return: 本元素前面的元素或节点组成的列表
         """
@@ -128,7 +128,7 @@ class ShadowRootElement(BaseElement):
         return self.parent_ele.eles(xpath, timeout=0.1)
 
     def afters(self, filter_loc=''):
-        """返回前面全部兄弟元素或节点组成的列表，可用查询语法筛选        \n
+        """返回前面全部兄弟元素或节点组成的列表，可用查询语法筛选
         :param filter_loc: 用于筛选元素的查询语法
         :return: 本元素后面的元素或节点组成的列表
         """
@@ -138,7 +138,7 @@ class ShadowRootElement(BaseElement):
         return eles1 + self.parent_ele.eles(xpath, timeout=0.1)
 
     def ele(self, loc_or_str, timeout=None):
-        """返回当前元素下级符合条件的第一个元素，默认返回                                   \n
+        """返回当前元素下级符合条件的第一个元素，默认返回
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 查找元素超时时间，默认与元素所在页面等待时间一致
         :return: DriverElement对象或属性、文本
@@ -146,7 +146,7 @@ class ShadowRootElement(BaseElement):
         return self._ele(loc_or_str, timeout)
 
     def eles(self, loc_or_str, timeout=None):
-        """返回当前元素下级所有符合条件的子元素                                              \n
+        """返回当前元素下级所有符合条件的子元素
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 查找元素超时时间，默认与元素所在页面等待时间一致
         :return: DriverElement对象或属性、文本组成的列表
@@ -154,21 +154,21 @@ class ShadowRootElement(BaseElement):
         return self._ele(loc_or_str, timeout=timeout, single=False)
 
     def s_ele(self, loc_or_str=None) -> Union[SessionElement, str, None]:
-        """查找第一个符合条件的元素以SessionElement形式返回，处理复杂页面时效率很高                 \n
+        """查找第一个符合条件的元素以SessionElement形式返回，处理复杂页面时效率很高
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
         """
         return make_session_ele(self, loc_or_str)
 
     def s_eles(self, loc_or_str):
-        """查找所有符合条件的元素以SessionElement列表形式返回，处理复杂页面时效率很高                 \n
+        """查找所有符合条件的元素以SessionElement列表形式返回，处理复杂页面时效率很高
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
         """
         return make_session_ele(self, loc_or_str, single=False)
 
     def _ele(self, loc_or_str, timeout=None, single=True, relative=False):
-        """返回当前元素下级符合条件的子元素，默认返回第一个                                                    \n
+        """返回当前元素下级符合条件的子元素，默认返回第一个
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 查找元素超时时间
         :param single: True则返回第一个，False则返回全部
@@ -197,7 +197,7 @@ class ShadowRootElement(BaseElement):
             return [make_driver_ele(self, f'css:{css}', True, timeout) for css in css_paths]
 
     def run_script(self, script, *args):
-        """执行js代码，传入自己为第一个参数  \n
+        """执行js代码，传入自己为第一个参数
         :param script: js文本
         :param args: 传入的参数
         :return: js执行结果
