@@ -3,24 +3,29 @@
 @Author  :   g1879
 @Contact :   g1879@qq.com
 """
+from pathlib import Path
 from time import sleep
+from warnings import warn
 
 from requests import Session
 from tldextract import extract
 
 from .base import BasePage
 from .chromium_base import ChromiumBase, Timeout
-from .chromium_page import ChromiumPage
-from .config import DriverOptions, SessionOptions, cookies_to_tuple
+from .chromium_driver import ChromiumDriver, CallMethodException
+from .chromium_page import ChromiumPage, ChromiumDownloadSetter
+from .configs.chromium_options import ChromiumOptions
+from .configs.driver_options import DriverOptions
+from .configs.session_options import SessionOptions
+from .functions.web import cookies_to_tuple
 from .session_page import SessionPage
-from .chromium_driver import ChromiumDriver
 
 
 class WebPage(SessionPage, ChromiumPage, BasePage):
     """整合浏览器和request的页面类"""
 
     def __init__(self, mode='d', timeout=None, tab_id=None, driver_or_options=None, session_or_options=None):
-        """初始化函数                                                                              \n
+        """初始化函数
         :param mode: 'd' 或 's'，即driver模式和session模式
         :param tab_id: 要控制的标签页id，不指定默认为激活的
         :param timeout: 超时时间，d模式时为寻找元素时间，s模式时为连接时间，默认10秒
@@ -30,27 +35,94 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
         self._mode = mode.lower()
         if self._mode not in ('s', 'd'):
             raise ValueError('mode参数只能是s或d。')
+        self._has_driver, self._has_session = (None, True) if self._mode == 's' else (True, None)
+
         self._debug = False
         self._debug_recorder = None
+        self.address = None
 
         self._session = None
         self._tab_obj = None
-        self._is_loading = False
-        self.timeouts = Timeout(self)
-        self._set_both_options(driver_or_options, session_or_options)
+        self._driver_options = None
+        self._session_options = None
         self._setting_tab_id = tab_id
-        self._has_driver, self._has_session = (None, True) if self._mode == 's' else (True, None)
         self._response = None
+        self._download_set = None
+
+        self._set_both_options(driver_or_options, session_or_options)
 
         if self._mode == 'd':
             self._to_d_mode()
 
-        t = timeout if timeout is not None else self.timeouts.implicit
+        t = timeout if isinstance(timeout, (int, float)) else self.timeouts.implicit
         super(ChromiumBase, self).__init__(t)  # 调用Base的__init__()
 
+    def _set_both_options(self, dr_opt, se_opt):
+        """处理两种模式的设置
+        :param dr_opt: ChromiumDriver或DriverOptions对象，为None则从ini读取，为False用默认信息创建
+        :param se_opt: Session、SessionOptions对象或配置信息，为None则从ini读取，为False用默认信息创建
+        :return: None
+        """
+        # 浏览器配置
+        if isinstance(dr_opt, ChromiumDriver):
+            self._connect_browser(dr_opt)
+            self._has_driver = True
+            # self._driver_options = None
+            dr_opt = False
+
+        else:
+            if dr_opt is None:
+                self._driver_options = ChromiumOptions()
+
+            elif dr_opt is False:
+                self._driver_options = ChromiumOptions(read_file=False)
+
+            elif isinstance(dr_opt, (ChromiumOptions, DriverOptions)):
+                self._driver_options = dr_opt
+
+            else:
+                raise TypeError('driver_or_options参数只能接收ChromiumDriver, ChromiumOptions、None或False。')
+
+        # Session配置
+        if isinstance(se_opt, Session):
+            self._session = se_opt
+            self._has_session = True
+            self._session_options = SessionOptions(read_file=False)
+            se_opt = False
+
+        else:
+            if se_opt is None:
+                self._session_options = SessionOptions()
+
+            elif se_opt is False:
+                self._session_options = SessionOptions(read_file=False)
+
+            elif isinstance(se_opt, SessionOptions):
+                self._session_options = se_opt
+
+            else:
+                raise TypeError('session_or_options参数只能接收Session, SessionOptions、None或False。')
+
+        # 通用配置
+        self._timeouts = Timeout(self)
+        self._page_load_strategy = self._driver_options.page_load_strategy
+        self._download_path = None
+        if se_opt is not False:
+            self.set_timeouts(implicit=self._session_options.timeout)
+            self._download_path = self._session_options.download_path
+
+        if dr_opt is not False:
+            t = self._driver_options.timeouts
+            self.set_timeouts(t['implicit'], t['pageLoad'], t['script'])
+            self._download_path = self._driver_options.download_path
+
+    def _set_options(self):
+        """覆盖父类同名方法"""
+        pass
+
     def __call__(self, loc_or_str, timeout=None):
-        """在内部查找元素                                            \n
-        例：ele = page('@id=ele_id')                               \n
+        """在内部查找元素
+        例：ele = page('@id=ele_id')
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 超时时间
         :return: 子元素对象
@@ -60,7 +132,6 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
         elif self._mode == 's':
             return super().__call__(loc_or_str)
 
-    # -----------------共有属性和方法-------------------
     @property
     def url(self):
         """返回当前url"""
@@ -147,14 +218,31 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
 
     @timeout.setter
     def timeout(self, second):
-        """设置通用超时时间           \n
+        """设置通用超时时间
         :param second: 秒数
         :return: None
         """
         self.set_timeouts(implicit=second)
 
+    @property
+    def download_path(self):
+        """返回默认下载路径"""
+        return super(SessionPage, self).download_path
+
+    @property
+    def download_set(self):
+        """返回下载设置对象"""
+        if self._download_set is None:
+            self._download_set = WebPageDownloadSetter(self)
+        return self._download_set
+
+    @property
+    def download(self):
+        """返回下载器对象"""
+        return self.download_set._switched_DownloadKit
+
     def get(self, url, show_errmsg=False, retry=None, interval=None, timeout=None, **kwargs):
-        """跳转到一个url                                         \n
+        """跳转到一个url
         :param url: 目标url
         :param show_errmsg: 是否显示和抛出异常
         :param retry: 重试次数
@@ -170,8 +258,21 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
                 timeout = self.timeouts.page_load if self._has_driver else self.timeout
             return super().get(url, show_errmsg, retry, interval, timeout, **kwargs)
 
+    def post(self, url: str, data=None, show_errmsg=False, retry=None, interval=None, **kwargs):
+        """用post方式跳转到url，会切换到s模式
+        :param url: 目标url
+        :param data: post方式时提交的数据
+        :param show_errmsg: 是否显示和抛出异常
+        :param retry: 重试次数
+        :param interval: 重试间隔（秒）
+        :param kwargs: 连接参数
+        :return: url是否可用
+        """
+        self.change_mode('s', go=False)
+        return super().post(url, data, show_errmsg, retry, interval, **kwargs)
+
     def ele(self, loc_or_ele, timeout=None):
-        """返回第一个符合条件的元素、属性或节点文本                               \n
+        """返回第一个符合条件的元素、属性或节点文本
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :param timeout: 查找元素超时时间，默认与页面等待时间一致
         :return: 元素对象或属性、文本节点文本
@@ -182,7 +283,7 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
             return super(SessionPage, self).ele(loc_or_ele, timeout=timeout)
 
     def eles(self, loc_or_str, timeout=None):
-        """返回页面中所有符合条件的元素、属性或节点文本                                \n
+        """返回页面中所有符合条件的元素、属性或节点文本
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 查找元素超时时间，默认与页面等待时间一致
         :return: 元素对象或属性、文本组成的列表
@@ -193,7 +294,7 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
             return super(SessionPage, self).eles(loc_or_str, timeout=timeout)
 
     def s_ele(self, loc_or_ele=None):
-        """查找第一个符合条件的元素以SessionElement形式返回，d模式处理复杂页面时效率很高                 \n
+        """查找第一个符合条件的元素以SessionElement形式返回，d模式处理复杂页面时效率很高
         :param loc_or_ele: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
         """
@@ -203,7 +304,7 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
             return super(SessionPage, self).s_ele(loc_or_ele)
 
     def s_eles(self, loc_or_str):
-        """查找所有符合条件的元素以SessionElement形式返回，d模式处理复杂页面时效率很高                 \n
+        """查找所有符合条件的元素以SessionElement形式返回，d模式处理复杂页面时效率很高
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象或属性、文本组成的列表
         """
@@ -213,9 +314,9 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
             return super(SessionPage, self).s_eles(loc_or_str)
 
     def change_mode(self, mode=None, go=True, copy_cookies=True):
-        """切换模式，接收's'或'd'，除此以外的字符串会切换为 d 模式                         \n
-        如copy_cookies为True，切换时会把当前模式的cookies复制到目标模式                   \n
-        切换后，如果go是True，调用相应的get函数使访问的页面同步                            \n
+        """切换模式，接收's'或'd'，除此以外的字符串会切换为 d 模式
+        如copy_cookies为True，切换时会把当前模式的cookies复制到目标模式
+        切换后，如果go是True，调用相应的get函数使访问的页面同步
         :param mode: 模式字符串
         :param go: 是否跳转到原模式的url
         :param copy_cookies: 是否复制cookies到目标模式
@@ -255,7 +356,7 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
                         self.get(url)
 
     def cookies_to_session(self, copy_user_agent=True):
-        """把driver对象的cookies复制到session对象    \n
+        """把driver对象的cookies复制到session对象
         :param copy_user_agent: 是否复制ua信息
         :return: None
         """
@@ -279,7 +380,7 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
         self.set_cookies(cookies, set_driver=True)
 
     def get_cookies(self, as_dict=False, all_domains=False):
-        """返回cookies                               \n
+        """返回cookies
         :param as_dict: 是否以字典方式返回
         :param all_domains: 是否返回所有域的cookies
         :return: cookies信息
@@ -290,6 +391,10 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
             return self._get_driver_cookies(as_dict)
 
     def _get_driver_cookies(self, as_dict=False):
+        """获取浏览器cookies
+        :param as_dict: 以dict形式返回
+        :return: cookies信息
+        """
         cookies = self._tab_obj.Network.getCookies()['cookies']
         if as_dict:
             return {cookie['name']: cookie['value'] for cookie in cookies}
@@ -297,7 +402,7 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
             return cookies
 
     def set_cookies(self, cookies, set_session=False, set_driver=False):
-        """添加cookies信息到浏览器或session对象                                                 \n
+        """添加cookies信息到浏览器或session对象
         :param cookies: 可以接收`CookieJar`、`list`、`tuple`、`str`、`dict`格式的`cookies`
         :param set_session: 是否设置到Session对象
         :param set_driver: 是否设置到浏览器
@@ -321,7 +426,7 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
             super().set_cookies(cookies)
 
     def set_headers(self, headers: dict) -> None:
-        """设置固定发送的headers                        \n
+        """设置固定发送的headers
         :param headers: dict格式的headers数据
         :return: None
         """
@@ -349,29 +454,8 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
             self._response = None
             self._has_session = None
 
-    # ----------------重写SessionPage的函数-----------------------
-    def post(self, url: str, data=None, show_errmsg=False, retry=None, interval=None, **kwargs):
-        """用post方式跳转到url，会切换到s模式                        \n
-        :param url: 目标url
-        :param data: post方式时提交的数据
-        :param show_errmsg: 是否显示和抛出异常
-        :param retry: 重试次数
-        :param interval: 重试间隔（秒）
-        :param kwargs: 连接参数
-        :return: url是否可用
-        """
-        self.change_mode('s', go=False)
-        return super().post(url, data, show_errmsg, retry, interval, **kwargs)
-
-    @property
-    def download(self):
-        """返回下载器对象"""
-        if self.mode == 'd':
-            self.cookies_to_session()
-        return super().download
-
     def _ele(self, loc_or_ele, timeout=None, single=True, relative=False):
-        """返回页面中符合条件的元素、属性或节点文本，默认返回第一个                                               \n
+        """返回页面中符合条件的元素、属性或节点文本，默认返回第一个
         :param loc_or_ele: 元素的定位信息，可以是元素对象，loc元组，或查询字符串
         :param timeout: 查找元素超时时间，d模式专用
         :param single: True则返回第一个，False则返回全部
@@ -382,62 +466,6 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
         elif self._mode == 'd':
             return super(SessionPage, self)._ele(loc_or_ele, timeout=timeout, single=single, relative=relative)
 
-    def _set_both_options(self, dr_opt, se_opt):
-        """处理两种模式的设置
-        :param dr_opt: ChromiumDriver或DriverOptions对象，为None则从ini读取，为False用默认信息创建
-        :param se_opt: Session、SessionOptions对象或配置信息，为None则从ini读取，为False用默认信息创建
-        :return: None
-        """
-        if isinstance(dr_opt, ChromiumDriver):
-            self._connect_browser(dr_opt)
-            self._has_driver = True
-            self._driver_options = None
-            dr_opt = False
-
-        else:
-            if dr_opt is None:
-                self._driver_options = DriverOptions()
-
-            elif dr_opt is False:
-                self._driver_options = DriverOptions(read_file=False)
-
-            elif isinstance(dr_opt, DriverOptions):
-                self._driver_options = dr_opt
-
-            else:
-                raise TypeError('driver_or_options参数只能接收ChromiumDriver, DriverOptions、None或False。')
-
-        if isinstance(se_opt, Session):
-            self._session = se_opt
-            self._has_session = True
-            self._session_options = None
-            se_opt = False
-
-        else:
-            if se_opt is None:
-                so = SessionOptions().as_dict()
-
-            elif se_opt is False:
-                so = SessionOptions(read_file=False).as_dict()
-
-            elif isinstance(se_opt, SessionOptions):
-                so = se_opt.as_dict()
-
-            elif isinstance(se_opt, dict):
-                so = se_opt
-
-            else:
-                raise TypeError('session_or_options参数只能接收Session, dict, SessionOptions、None或False。')
-
-            self._session_options = so
-
-        if se_opt is not False:
-            self.set_timeouts(implicit=self._session_options.get('timeout', 10))
-
-        if dr_opt is not False:
-            t = self._driver_options.timeouts
-            self.set_timeouts(t['implicit'], t['pageLoad'], t['script'])
-
     def quit(self):
         """关闭浏览器，关闭session"""
         if self._has_session:
@@ -450,3 +478,67 @@ class WebPage(SessionPage, ChromiumPage, BasePage):
             self._tab_obj.stop()
             self._tab_obj = None
             self._has_driver = None
+
+
+class WebPageDownloadSetter(ChromiumDownloadSetter):
+    """用于设置下载参数的类"""
+
+    def __init__(self, page):
+        super().__init__(page)
+        self._session = page.session
+
+    @property
+    def _switched_DownloadKit(self):
+        """返回从浏览器同步cookies后的Session对象"""
+        if self._page.mode == 'd':
+            self._cookies_to_session()
+        return self.DownloadKit
+
+    def save_path(self, path):
+        """设置下载路径
+        :param path: 下载路径
+        :return: None
+        """
+        path = path or ''
+        path = Path(path).absolute()
+        path.mkdir(parents=True, exist_ok=True)
+        path = str(path)
+        self._page._download_path = path
+        self.DownloadKit.goal_path = path
+
+        if self._page._has_driver:
+            try:
+                self._page.browser_driver.Browser.setDownloadBehavior(behavior=self._behavior, downloadPath=path,
+                                                                      eventsEnabled=True)
+            except CallMethodException:
+                warn('\n您的浏览器版本太低，用新标签页下载文件可能崩溃，建议升级。')
+                self._page.run_cdp('Page.setDownloadBehavior', behavior=self._behavior, downloadPath=path,
+                                   not_change=True)
+
+    def by_browser(self):
+        """设置使用浏览器下载文件"""
+        if not self._page._has_driver:
+            raise RuntimeError('浏览器未连接。')
+
+        try:
+            self._page.browser_driver.Browser.setDownloadBehavior(behavior='allow', eventsEnabled=True,
+                                                                  downloadPath=self._page.download_path)
+            self._page.browser_driver.Browser.downloadWillBegin = self._download_by_browser
+
+        except CallMethodException:
+            warn('\n您的浏览器版本太低，用新标签页下载文件可能崩溃，建议升级。')
+            self._page.driver.Page.setDownloadBehavior(behavior='allow', downloadPath=self._page.download_path)
+            self._page.driver.Page.downloadWillBegin = self._download_by_browser
+
+        self._behavior = 'allow'
+
+    def by_DownloadKit(self):
+        """设置使用DownloadKit下载文件"""
+        if self._page._has_driver:
+            try:
+                self._page.browser_driver.Browser.setDownloadBehavior(behavior='deny', eventsEnabled=True)
+                self._page.browser_driver.Browser.downloadWillBegin = self._download_by_DownloadKit
+            except CallMethodException:
+                raise RuntimeError('您的浏览器版本太低，不支持此方法，请升级。')
+
+        self._behavior = 'deny'
